Crate wasm_bindgen_shared

Crate wasm_bindgen_shared 

Modules

identifier
tys

Macros

shared_api

Constants

SCHEMA_VERSION

Functions

dynamic_union_variant
escape_string
free_function
free_function_export_name
new_function
qualified_name
Compute a “qualified name” by prepending the namespace (joined with __) to the js_name. When there is no namespace, this returns the js_name unchanged. This is used to disambiguate internal wasm symbols when the same js_name appears in different namespaces. __ is used as the separator because double underscores are unlikely to appear in user-defined names.
struct_field_get
struct_field_set
struct_function_export_name
unwrap_function
upcast_function
Symbol name of the wasm export that upcasts a *const WasmRefCell<Child> pointer to a cloned Rc<WasmRefCell<Parent>> raw pointer. Used by the macro codegen and by cli-support’s JS emission to call each other.
version