Crate wasm_bindgen_shared

Crate wasm_bindgen_shared 

Modules

identifier
tys

Macros

shared_api

Constants

SCHEMA_VERSION

Functions

escape_string
free_function
free_function_export_name
new_function
qualified_name
Compute a “qualified name” by prepending the namespace (joined with __) to the js_name. When there is no namespace, this returns the js_name unchanged. This is used to disambiguate internal wasm symbols when the same js_name appears in different namespaces. __ is used as the separator because double underscores are unlikely to appear in user-defined names.
struct_field_get
struct_field_set
struct_function_export_name
unwrap_function
version