Modules
Macros
Constants
Functions
- escape_
string - free_
function - free_
function_ export_ name - new_
function - qualified_
name - Compute a “qualified name” by prepending the namespace (joined with
__) to the js_name. When there is no namespace, this returns the js_name unchanged. This is used to disambiguate internal wasm symbols when the same js_name appears in different namespaces.__is used as the separator because double underscores are unlikely to appear in user-defined names. - struct_
field_ get - struct_
field_ set - struct_
function_ export_ name - unwrap_
function - version