pub fn qualified_name(
js_namespace: Option<&[impl AsRef<str>]>,
js_name: &str,
) -> StringExpand description
Compute a “qualified name” by prepending the namespace (joined with __) to the js_name.
When there is no namespace, this returns the js_name unchanged.
This is used to disambiguate internal wasm symbols when the same js_name
appears in different namespaces. __ is used as the separator because
double underscores are unlikely to appear in user-defined names.